@@ -28,6 +28,16 @@ $(function() {
 		}
 	}
 
+	// Show a '*' after the tab name if it is modified	
+	var showStarAfterNameIfModified = function(editor) {
+		if(editor.isClean()) {
+			$("#myTab > li.active > a > span").text('');
+		} else {
+			$("#myTab > li.active > a > span").text(" *");
+		}
+	};
+
+
 	var tabId = 1;
 	window.AddEditorTab = function(tabName, filename, mode, contents) {
 		
@@ -41,12 +51,20 @@ $(function() {
 
 		// Add the tab component
 		$("#myTab").append('<li><a href="#' + tabId + '" data-toggle="tab">' + tabName + '&nbsp;<span></span>&nbsp;&nbsp;<i class="icon-remove"></i></a></li>');
+		
+		// Add the new tab button
+		$("#myTab li.farabi-add-tab").remove();
+		$("#myTab").append('<li class="farabi-add-tab">&nbsp;<i class="icon-plus-sign"></i></li>');
+		
+		// When add file is clicked, new file action is trigger
+		$(".farabi-add-tab").click(function() {
+			$(document).trigger('action-new-file');
+		});
 
 		// Add the tab editor
 		$("#myTabContent").append(
 			'<div class="tab-pane" id="' + tabId + '">' +
 				'<div class="span6 farabi-bordered" id="editor-border">' +
-					'<b>Editor:</b>' +
 					'<textarea id="'+editorId+'" name="' + editorId +'" class="editor"></textarea>' +
 					'<div class="editor_stats" class="pull-right"></div>' +
 				'</div>' +
@@ -66,7 +84,7 @@ $(function() {
 		});
 		
 		// When the close file icon is clicked
-		$("i", "#myTab").click(function(e) {
+		$("i.icon-remove", "#myTab").click(function(e) {
 			
 			// Update currentEditorId
 			var $tab = $(this).parent();
@@ -144,14 +162,7 @@ $(function() {
 
 				}, 250);
 
-				// Show a '*' after the tab name if it is modified
-				var isClean = cm.isClean();
-				if(isClean) {
-					$("#myTab > li.active > a > span").text('');
-				} else {
-					$("#myTab > li.active > a > span").text(" *");
-				}
-				
+				showStarAfterNameIfModified(cm);
 		});
 
 		
@@ -379,7 +390,7 @@ $(function() {
 
 	var onCloseFocusEditor = function () {
 		var editor = GetCurrentEditor();
-		if(!editor) {
+		if(editor) {
 			editor.focus();
 		}
 	};
@@ -445,6 +456,7 @@ $(function() {
 		}
 	});
 
+	// Handle the close all files action
 	$(document).on('action-close-all-files', function() {
 		$("#myTab > li").remove();
 		$("#myTabContent > div").remove();
@@ -456,19 +468,19 @@ $(function() {
 		AddEditorTab();
 	});
 
+	// Handle the save file action
 	$(document).on('action-save-file', function() {
 		var editor = GetCurrentEditor();
 		var filename = GetCurrentFilename();
 		$.post('/save-file', {"filename": filename, "source": editor.getValue()}, function(data) {
-			if(data.error == '') {
-				alert("File saved!");
+			if(data.err == '') {
+				editor.markClean();
+				showStarAfterNameIfModified(editor);
 			} else {
-				alert('Error:\n' + data.error);
+				alert('Error:\n' + data.err);
 			}
 		});
 	});
-
-	
 	
 	// Add an empty one editor tab on startup
 	AddEditorTab();
