@@ -94,7 +94,6 @@ $(function() {
 	$actionsDialog.keyup(function(e) {
 		if(e.keyCode == 13) {
 			// ENTER triggers an action
-			e.preventDefault();
 			$("#ok-button", $actionsDialog).click();
 		}
 	});
@@ -104,12 +103,7 @@ $(function() {
 		var keyCode = e.keyCode;
 		if(keyCode == 40) {
 			// DOWN ARROW triggers a focus on the matched actions list
-			e.preventDefault();
 			$("#matched-actions", $actionsDialog).focus();
-		} else if(keyCode == 13) {
-			// ENTER triggers an action
-			e.preventDefault();
-			$("#ok-button", $actionsDialog).click();
 		}
 	});
 	
