@@ -50,18 +50,13 @@ $(function() {
 	$("#file", $openFileDialog).keyup(function(e) {
 		var keyCode = e.keyCode;
 		if(keyCode == 40) {
-			e.preventDefault();
 			$("#matched-files", $openFileDialog).focus();
-		} else if(keyCode == 13) {
-			e.preventDefault();
-			$("#ok-button", $openFileDialog).click();
 		}
 	});
 
 	$($openFileDialog).keyup(function(e) {
 		var keyCode = e.keyCode;
 		if(keyCode == 13) {
-			e.preventDefault();
 			$("#ok-button", $openFileDialog).click();
 		}
 	});
@@ -89,10 +84,7 @@ $(function() {
 			data:    { "filename": filename },
 			success: function(result) {
 				if(result.ok) {
-					AddEditorTab(result.filename);
-					var editor = GetCurrentEditor();
-					editor.setValue(result.value);
-					ChangeMode(editor, result.mode);
+					AddEditorTab(result.filename, filename, result.mode, result.value);
 				} else {
 					alert(result.value);
 				}
