@@ -21,10 +21,6 @@ $(function() {
 				"runtime" : $("#runtime :selected", $replDialog).attr("id"),
 			},
 			success: function(result) {
-				if(!result.ok) {
-					alert("Error: " + result.err);
-					return;
-				}
 				var oldOutput = $("#output", $replDialog).val();
 				if(result.err != '') {
 					result.out += "\nError: " + result.err;
@@ -44,10 +40,6 @@ $(function() {
 
 	};
 	
-	$("#command", $replDialog).click(function() {
-		evalCommand();
-	});
-	
 	$("#run-button", $replDialog).click(function() {
 		evalCommand();
 	});
